# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: Node.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import Location_pb2 as Location__pb2
from . import Tag_pb2 as Tag__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='Node.proto',
  package='org.openstreetmap.atlas.proto',
  syntax='proto2',
  serialized_options=b'B\020ProtoNodeWrapperP\001',
  serialized_pb=b'\n\nNode.proto\x12\x1dorg.openstreetmap.atlas.proto\x1a\x0eLocation.proto\x1a\tTag.proto\"\x8e\x01\n\tProtoNode\x12\n\n\x02id\x18\x01 \x01(\x03\x12>\n\x08location\x18\x02 \x01(\x0b\x32,.org.openstreetmap.atlas.proto.ProtoLocation\x12\x35\n\x04tags\x18\x05 \x03(\x0b\x32\'.org.openstreetmap.atlas.proto.ProtoTagB\x14\x42\x10ProtoNodeWrapperP\x01'
  ,
  dependencies=[Location__pb2.DESCRIPTOR,Tag__pb2.DESCRIPTOR,])




_PROTONODE = _descriptor.Descriptor(
  name='ProtoNode',
  full_name='org.openstreetmap.atlas.proto.ProtoNode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='org.openstreetmap.atlas.proto.ProtoNode.id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='location', full_name='org.openstreetmap.atlas.proto.ProtoNode.location', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tags', full_name='org.openstreetmap.atlas.proto.ProtoNode.tags', index=2,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=73,
  serialized_end=215,
)

_PROTONODE.fields_by_name['location'].message_type = Location__pb2._PROTOLOCATION
_PROTONODE.fields_by_name['tags'].message_type = Tag__pb2._PROTOTAG
DESCRIPTOR.message_types_by_name['ProtoNode'] = _PROTONODE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ProtoNode = _reflection.GeneratedProtocolMessageType('ProtoNode', (_message.Message,), {
  'DESCRIPTOR' : _PROTONODE,
  '__module__' : 'Node_pb2'
  # @@protoc_insertion_point(class_scope:org.openstreetmap.atlas.proto.ProtoNode)
  })
_sym_db.RegisterMessage(ProtoNode)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
