# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ProtoLongArray.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='ProtoLongArray.proto',
  package='org.openstreetmap.atlas.proto',
  syntax='proto2',
  serialized_options=b'B\025ProtoLongArrayWrapperP\001',
  serialized_pb=b'\n\x14ProtoLongArray.proto\x12\x1dorg.openstreetmap.atlas.proto\"0\n\x0eProtoLongArray\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08\x65lements\x18\x02 \x03(\x03\x42\x19\x42\x15ProtoLongArrayWrapperP\x01'
)




_PROTOLONGARRAY = _descriptor.Descriptor(
  name='ProtoLongArray',
  full_name='org.openstreetmap.atlas.proto.ProtoLongArray',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='org.openstreetmap.atlas.proto.ProtoLongArray.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='elements', full_name='org.openstreetmap.atlas.proto.ProtoLongArray.elements', index=1,
      number=2, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55,
  serialized_end=103,
)

DESCRIPTOR.message_types_by_name['ProtoLongArray'] = _PROTOLONGARRAY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ProtoLongArray = _reflection.GeneratedProtocolMessageType('ProtoLongArray', (_message.Message,), {
  'DESCRIPTOR' : _PROTOLONGARRAY,
  '__module__' : 'ProtoLongArray_pb2'
  # @@protoc_insertion_point(class_scope:org.openstreetmap.atlas.proto.ProtoLongArray)
  })
_sym_db.RegisterMessage(ProtoLongArray)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
