# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ProtoIntegerStringDictionary.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='ProtoIntegerStringDictionary.proto',
  package='org.openstreetmap.atlas.proto',
  syntax='proto2',
  serialized_options=b'B#ProtoIntegerStringDictionaryWrapperP\001',
  serialized_pb=b'\n\"ProtoIntegerStringDictionary.proto\x12\x1dorg.openstreetmap.atlas.proto\"T\n\x1cProtoIntegerStringDictionary\x12\x14\n\x0c\x63urrentIndex\x18\x01 \x01(\x05\x12\x0f\n\x07indexes\x18\x02 \x03(\x05\x12\r\n\x05words\x18\x03 \x03(\tB\'B#ProtoIntegerStringDictionaryWrapperP\x01'
)




_PROTOINTEGERSTRINGDICTIONARY = _descriptor.Descriptor(
  name='ProtoIntegerStringDictionary',
  full_name='org.openstreetmap.atlas.proto.ProtoIntegerStringDictionary',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='currentIndex', full_name='org.openstreetmap.atlas.proto.ProtoIntegerStringDictionary.currentIndex', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='indexes', full_name='org.openstreetmap.atlas.proto.ProtoIntegerStringDictionary.indexes', index=1,
      number=2, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='words', full_name='org.openstreetmap.atlas.proto.ProtoIntegerStringDictionary.words', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=69,
  serialized_end=153,
)

DESCRIPTOR.message_types_by_name['ProtoIntegerStringDictionary'] = _PROTOINTEGERSTRINGDICTIONARY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ProtoIntegerStringDictionary = _reflection.GeneratedProtocolMessageType('ProtoIntegerStringDictionary', (_message.Message,), {
  'DESCRIPTOR' : _PROTOINTEGERSTRINGDICTIONARY,
  '__module__' : 'ProtoIntegerStringDictionary_pb2'
  # @@protoc_insertion_point(class_scope:org.openstreetmap.atlas.proto.ProtoIntegerStringDictionary)
  })
_sym_db.RegisterMessage(ProtoIntegerStringDictionary)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
