# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: Relation.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import Tag_pb2 as Tag__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='Relation.proto',
  package='org.openstreetmap.atlas.proto',
  syntax='proto2',
  serialized_options=b'B\024ProtoRelationWrapperP\001',
  serialized_pb=b'\n\x0eRelation.proto\x12\x1dorg.openstreetmap.atlas.proto\x1a\tTag.proto\"\xf5\x02\n\rProtoRelation\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x35\n\x04tags\x18\x02 \x03(\x0b\x32\'.org.openstreetmap.atlas.proto.ProtoTag\x12H\n\x05\x62\x65\x61ns\x18\x03 \x03(\x0b\x32\x39.org.openstreetmap.atlas.proto.ProtoRelation.RelationBean\x1a\x84\x01\n\x0cRelationBean\x12\x10\n\x08memberId\x18\x01 \x01(\x03\x12\x12\n\nmemberRole\x18\x02 \x01(\t\x12N\n\nmemberType\x18\x03 \x01(\x0e\x32:.org.openstreetmap.atlas.proto.ProtoRelation.ProtoItemType\"P\n\rProtoItemType\x12\x08\n\x04NODE\x10\x00\x12\x08\n\x04\x45\x44GE\x10\x01\x12\x08\n\x04\x41REA\x10\x02\x12\x08\n\x04LINE\x10\x03\x12\t\n\x05POINT\x10\x04\x12\x0c\n\x08RELATION\x10\x05\x42\x18\x42\x14ProtoRelationWrapperP\x01'
  ,
  dependencies=[Tag__pb2.DESCRIPTOR,])



_PROTORELATION_PROTOITEMTYPE = _descriptor.EnumDescriptor(
  name='ProtoItemType',
  full_name='org.openstreetmap.atlas.proto.ProtoRelation.ProtoItemType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NODE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EDGE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AREA', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LINE', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='POINT', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RELATION', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=354,
  serialized_end=434,
)
_sym_db.RegisterEnumDescriptor(_PROTORELATION_PROTOITEMTYPE)


_PROTORELATION_RELATIONBEAN = _descriptor.Descriptor(
  name='RelationBean',
  full_name='org.openstreetmap.atlas.proto.ProtoRelation.RelationBean',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='memberId', full_name='org.openstreetmap.atlas.proto.ProtoRelation.RelationBean.memberId', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='memberRole', full_name='org.openstreetmap.atlas.proto.ProtoRelation.RelationBean.memberRole', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='memberType', full_name='org.openstreetmap.atlas.proto.ProtoRelation.RelationBean.memberType', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=220,
  serialized_end=352,
)

_PROTORELATION = _descriptor.Descriptor(
  name='ProtoRelation',
  full_name='org.openstreetmap.atlas.proto.ProtoRelation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='org.openstreetmap.atlas.proto.ProtoRelation.id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tags', full_name='org.openstreetmap.atlas.proto.ProtoRelation.tags', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='beans', full_name='org.openstreetmap.atlas.proto.ProtoRelation.beans', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_PROTORELATION_RELATIONBEAN, ],
  enum_types=[
    _PROTORELATION_PROTOITEMTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=61,
  serialized_end=434,
)

_PROTORELATION_RELATIONBEAN.fields_by_name['memberType'].enum_type = _PROTORELATION_PROTOITEMTYPE
_PROTORELATION_RELATIONBEAN.containing_type = _PROTORELATION
_PROTORELATION.fields_by_name['tags'].message_type = Tag__pb2._PROTOTAG
_PROTORELATION.fields_by_name['beans'].message_type = _PROTORELATION_RELATIONBEAN
_PROTORELATION_PROTOITEMTYPE.containing_type = _PROTORELATION
DESCRIPTOR.message_types_by_name['ProtoRelation'] = _PROTORELATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ProtoRelation = _reflection.GeneratedProtocolMessageType('ProtoRelation', (_message.Message,), {

  'RelationBean' : _reflection.GeneratedProtocolMessageType('RelationBean', (_message.Message,), {
    'DESCRIPTOR' : _PROTORELATION_RELATIONBEAN,
    '__module__' : 'Relation_pb2'
    # @@protoc_insertion_point(class_scope:org.openstreetmap.atlas.proto.ProtoRelation.RelationBean)
    })
  ,
  'DESCRIPTOR' : _PROTORELATION,
  '__module__' : 'Relation_pb2'
  # @@protoc_insertion_point(class_scope:org.openstreetmap.atlas.proto.ProtoRelation)
  })
_sym_db.RegisterMessage(ProtoRelation)
_sym_db.RegisterMessage(ProtoRelation.RelationBean)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
