# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: Tag.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='Tag.proto',
  package='org.openstreetmap.atlas.proto',
  syntax='proto2',
  serialized_options=b'B\017ProtoTagWrapperP\001',
  serialized_pb=b'\n\tTag.proto\x12\x1dorg.openstreetmap.atlas.proto\"&\n\x08ProtoTag\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\tB\x13\x42\x0fProtoTagWrapperP\x01'
)




_PROTOTAG = _descriptor.Descriptor(
  name='ProtoTag',
  full_name='org.openstreetmap.atlas.proto.ProtoTag',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='org.openstreetmap.atlas.proto.ProtoTag.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='org.openstreetmap.atlas.proto.ProtoTag.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=44,
  serialized_end=82,
)

DESCRIPTOR.message_types_by_name['ProtoTag'] = _PROTOTAG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ProtoTag = _reflection.GeneratedProtocolMessageType('ProtoTag', (_message.Message,), {
  'DESCRIPTOR' : _PROTOTAG,
  '__module__' : 'Tag_pb2'
  # @@protoc_insertion_point(class_scope:org.openstreetmap.atlas.proto.ProtoTag)
  })
_sym_db.RegisterMessage(ProtoTag)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
