# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ProtoPackedTagStore.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import ProtoIntegerArrayOfArrays_pb2 as ProtoIntegerArrayOfArrays__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ProtoPackedTagStore.proto',
  package='org.openstreetmap.atlas.proto',
  syntax='proto2',
  serialized_options=b'B\032ProtoPackedTagStoreWrapperP\001',
  serialized_pb=b'\n\x19ProtoPackedTagStore.proto\x12\x1dorg.openstreetmap.atlas.proto\x1a\x1fProtoIntegerArrayOfArrays.proto\"\xb6\x01\n\x13ProtoPackedTagStore\x12\r\n\x05index\x18\x01 \x01(\x03\x12\x46\n\x04keys\x18\x02 \x01(\x0b\x32\x38.org.openstreetmap.atlas.proto.ProtoIntegerArrayOfArrays\x12H\n\x06values\x18\x03 \x01(\x0b\x32\x38.org.openstreetmap.atlas.proto.ProtoIntegerArrayOfArraysB\x1e\x42\x1aProtoPackedTagStoreWrapperP\x01'
  ,
  dependencies=[ProtoIntegerArrayOfArrays__pb2.DESCRIPTOR,])




_PROTOPACKEDTAGSTORE = _descriptor.Descriptor(
  name='ProtoPackedTagStore',
  full_name='org.openstreetmap.atlas.proto.ProtoPackedTagStore',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='org.openstreetmap.atlas.proto.ProtoPackedTagStore.index', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keys', full_name='org.openstreetmap.atlas.proto.ProtoPackedTagStore.keys', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='values', full_name='org.openstreetmap.atlas.proto.ProtoPackedTagStore.values', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=94,
  serialized_end=276,
)

_PROTOPACKEDTAGSTORE.fields_by_name['keys'].message_type = ProtoIntegerArrayOfArrays__pb2._PROTOINTEGERARRAYOFARRAYS
_PROTOPACKEDTAGSTORE.fields_by_name['values'].message_type = ProtoIntegerArrayOfArrays__pb2._PROTOINTEGERARRAYOFARRAYS
DESCRIPTOR.message_types_by_name['ProtoPackedTagStore'] = _PROTOPACKEDTAGSTORE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ProtoPackedTagStore = _reflection.GeneratedProtocolMessageType('ProtoPackedTagStore', (_message.Message,), {
  'DESCRIPTOR' : _PROTOPACKEDTAGSTORE,
  '__module__' : 'ProtoPackedTagStore_pb2'
  # @@protoc_insertion_point(class_scope:org.openstreetmap.atlas.proto.ProtoPackedTagStore)
  })
_sym_db.RegisterMessage(ProtoPackedTagStore)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
