# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ProtoAtlas.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import Point_pb2 as Point__pb2
from . import Line_pb2 as Line__pb2
from . import Area_pb2 as Area__pb2
from . import Node_pb2 as Node__pb2
from . import Edge_pb2 as Edge__pb2
from . import Relation_pb2 as Relation__pb2
from . import ProtoAtlasMetaData_pb2 as ProtoAtlasMetaData__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ProtoAtlas.proto',
  package='org.openstreetmap.atlas.proto',
  syntax='proto2',
  serialized_options=b'B\021ProtoAtlasWrapperP\001',
  serialized_pb=b'\n\x10ProtoAtlas.proto\x12\x1dorg.openstreetmap.atlas.proto\x1a\x0bPoint.proto\x1a\nLine.proto\x1a\nArea.proto\x1a\nNode.proto\x1a\nEdge.proto\x1a\x0eRelation.proto\x1a\x18ProtoAtlasMetaData.proto\"\xc0\x04\n\nProtoAtlas\x12\x16\n\x0enumberOfPoints\x18\x01 \x01(\x03\x12\x39\n\x06points\x18\x02 \x03(\x0b\x32).org.openstreetmap.atlas.proto.ProtoPoint\x12\x15\n\rnumberOfLines\x18\x03 \x01(\x03\x12\x37\n\x05lines\x18\x04 \x03(\x0b\x32(.org.openstreetmap.atlas.proto.ProtoLine\x12\x15\n\rnumberOfAreas\x18\x05 \x01(\x03\x12\x37\n\x05\x61reas\x18\x06 \x03(\x0b\x32(.org.openstreetmap.atlas.proto.ProtoArea\x12\x15\n\rnumberOfNodes\x18\x07 \x01(\x03\x12\x37\n\x05nodes\x18\x08 \x03(\x0b\x32(.org.openstreetmap.atlas.proto.ProtoNode\x12\x15\n\rnumberOfEdges\x18\t \x01(\x03\x12\x37\n\x05\x65\x64ges\x18\n \x03(\x0b\x32(.org.openstreetmap.atlas.proto.ProtoEdge\x12\x19\n\x11numberOfRelations\x18\x0b \x01(\x03\x12?\n\trelations\x18\x0c \x03(\x0b\x32,.org.openstreetmap.atlas.proto.ProtoRelation\x12\x43\n\x08metaData\x18\r \x01(\x0b\x32\x31.org.openstreetmap.atlas.proto.ProtoAtlasMetaDataB\x15\x42\x11ProtoAtlasWrapperP\x01'
  ,
  dependencies=[Point__pb2.DESCRIPTOR,Line__pb2.DESCRIPTOR,Area__pb2.DESCRIPTOR,Node__pb2.DESCRIPTOR,Edge__pb2.DESCRIPTOR,Relation__pb2.DESCRIPTOR,ProtoAtlasMetaData__pb2.DESCRIPTOR,])




_PROTOATLAS = _descriptor.Descriptor(
  name='ProtoAtlas',
  full_name='org.openstreetmap.atlas.proto.ProtoAtlas',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='numberOfPoints', full_name='org.openstreetmap.atlas.proto.ProtoAtlas.numberOfPoints', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='points', full_name='org.openstreetmap.atlas.proto.ProtoAtlas.points', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numberOfLines', full_name='org.openstreetmap.atlas.proto.ProtoAtlas.numberOfLines', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lines', full_name='org.openstreetmap.atlas.proto.ProtoAtlas.lines', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numberOfAreas', full_name='org.openstreetmap.atlas.proto.ProtoAtlas.numberOfAreas', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='areas', full_name='org.openstreetmap.atlas.proto.ProtoAtlas.areas', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numberOfNodes', full_name='org.openstreetmap.atlas.proto.ProtoAtlas.numberOfNodes', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nodes', full_name='org.openstreetmap.atlas.proto.ProtoAtlas.nodes', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numberOfEdges', full_name='org.openstreetmap.atlas.proto.ProtoAtlas.numberOfEdges', index=8,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='edges', full_name='org.openstreetmap.atlas.proto.ProtoAtlas.edges', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numberOfRelations', full_name='org.openstreetmap.atlas.proto.ProtoAtlas.numberOfRelations', index=10,
      number=11, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='relations', full_name='org.openstreetmap.atlas.proto.ProtoAtlas.relations', index=11,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metaData', full_name='org.openstreetmap.atlas.proto.ProtoAtlas.metaData', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=155,
  serialized_end=731,
)

_PROTOATLAS.fields_by_name['points'].message_type = Point__pb2._PROTOPOINT
_PROTOATLAS.fields_by_name['lines'].message_type = Line__pb2._PROTOLINE
_PROTOATLAS.fields_by_name['areas'].message_type = Area__pb2._PROTOAREA
_PROTOATLAS.fields_by_name['nodes'].message_type = Node__pb2._PROTONODE
_PROTOATLAS.fields_by_name['edges'].message_type = Edge__pb2._PROTOEDGE
_PROTOATLAS.fields_by_name['relations'].message_type = Relation__pb2._PROTORELATION
_PROTOATLAS.fields_by_name['metaData'].message_type = ProtoAtlasMetaData__pb2._PROTOATLASMETADATA
DESCRIPTOR.message_types_by_name['ProtoAtlas'] = _PROTOATLAS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ProtoAtlas = _reflection.GeneratedProtocolMessageType('ProtoAtlas', (_message.Message,), {
  'DESCRIPTOR' : _PROTOATLAS,
  '__module__' : 'ProtoAtlas_pb2'
  # @@protoc_insertion_point(class_scope:org.openstreetmap.atlas.proto.ProtoAtlas)
  })
_sym_db.RegisterMessage(ProtoAtlas)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
