# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ProtoAtlasMetaData.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import Tag_pb2 as Tag__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ProtoAtlasMetaData.proto',
  package='org.openstreetmap.atlas.proto',
  syntax='proto2',
  serialized_options=b'B\031ProtoAtlasMetaDataWrapperP\001',
  serialized_pb=b'\n\x18ProtoAtlasMetaData.proto\x12\x1dorg.openstreetmap.atlas.proto\x1a\tTag.proto\"\xa8\x02\n\x12ProtoAtlasMetaData\x12\x12\n\nedgeNumber\x18\x01 \x01(\x03\x12\x12\n\nnodeNumber\x18\x02 \x01(\x03\x12\x12\n\nareaNumber\x18\x03 \x01(\x03\x12\x12\n\nlineNumber\x18\x04 \x01(\x03\x12\x13\n\x0bpointNumber\x18\x05 \x01(\x03\x12\x16\n\x0erelationNumber\x18\x06 \x01(\x03\x12\x10\n\x08original\x18\x07 \x01(\x08\x12\x13\n\x0b\x63odeVersion\x18\x08 \x01(\t\x12\x13\n\x0b\x64\x61taVersion\x18\t \x01(\t\x12\x0f\n\x07\x63ountry\x18\n \x01(\t\x12\x11\n\tshardName\x18\x0b \x01(\t\x12\x35\n\x04tags\x18\x0c \x03(\x0b\x32\'.org.openstreetmap.atlas.proto.ProtoTagB\x1d\x42\x19ProtoAtlasMetaDataWrapperP\x01'
  ,
  dependencies=[Tag__pb2.DESCRIPTOR,])




_PROTOATLASMETADATA = _descriptor.Descriptor(
  name='ProtoAtlasMetaData',
  full_name='org.openstreetmap.atlas.proto.ProtoAtlasMetaData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='edgeNumber', full_name='org.openstreetmap.atlas.proto.ProtoAtlasMetaData.edgeNumber', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nodeNumber', full_name='org.openstreetmap.atlas.proto.ProtoAtlasMetaData.nodeNumber', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='areaNumber', full_name='org.openstreetmap.atlas.proto.ProtoAtlasMetaData.areaNumber', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lineNumber', full_name='org.openstreetmap.atlas.proto.ProtoAtlasMetaData.lineNumber', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pointNumber', full_name='org.openstreetmap.atlas.proto.ProtoAtlasMetaData.pointNumber', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='relationNumber', full_name='org.openstreetmap.atlas.proto.ProtoAtlasMetaData.relationNumber', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='original', full_name='org.openstreetmap.atlas.proto.ProtoAtlasMetaData.original', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='codeVersion', full_name='org.openstreetmap.atlas.proto.ProtoAtlasMetaData.codeVersion', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dataVersion', full_name='org.openstreetmap.atlas.proto.ProtoAtlasMetaData.dataVersion', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='country', full_name='org.openstreetmap.atlas.proto.ProtoAtlasMetaData.country', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shardName', full_name='org.openstreetmap.atlas.proto.ProtoAtlasMetaData.shardName', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tags', full_name='org.openstreetmap.atlas.proto.ProtoAtlasMetaData.tags', index=11,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=71,
  serialized_end=367,
)

_PROTOATLASMETADATA.fields_by_name['tags'].message_type = Tag__pb2._PROTOTAG
DESCRIPTOR.message_types_by_name['ProtoAtlasMetaData'] = _PROTOATLASMETADATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ProtoAtlasMetaData = _reflection.GeneratedProtocolMessageType('ProtoAtlasMetaData', (_message.Message,), {
  'DESCRIPTOR' : _PROTOATLASMETADATA,
  '__module__' : 'ProtoAtlasMetaData_pb2'
  # @@protoc_insertion_point(class_scope:org.openstreetmap.atlas.proto.ProtoAtlasMetaData)
  })
_sym_db.RegisterMessage(ProtoAtlasMetaData)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
