# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: Location.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import Tag_pb2 as Tag__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='Location.proto',
  package='org.openstreetmap.atlas.proto',
  syntax='proto2',
  serialized_options=b'B\024ProtoLocationWrapperP\001',
  serialized_pb=b'\n\x0eLocation.proto\x12\x1dorg.openstreetmap.atlas.proto\x1a\tTag.proto\"4\n\rProtoLocation\x12\x10\n\x08latitude\x18\x01 \x01(\x05\x12\x11\n\tlongitude\x18\x02 \x01(\x05\x42\x18\x42\x14ProtoLocationWrapperP\x01'
  ,
  dependencies=[Tag__pb2.DESCRIPTOR,])




_PROTOLOCATION = _descriptor.Descriptor(
  name='ProtoLocation',
  full_name='org.openstreetmap.atlas.proto.ProtoLocation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='latitude', full_name='org.openstreetmap.atlas.proto.ProtoLocation.latitude', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='longitude', full_name='org.openstreetmap.atlas.proto.ProtoLocation.longitude', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=60,
  serialized_end=112,
)

DESCRIPTOR.message_types_by_name['ProtoLocation'] = _PROTOLOCATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ProtoLocation = _reflection.GeneratedProtocolMessageType('ProtoLocation', (_message.Message,), {
  'DESCRIPTOR' : _PROTOLOCATION,
  '__module__' : 'Location_pb2'
  # @@protoc_insertion_point(class_scope:org.openstreetmap.atlas.proto.ProtoLocation)
  })
_sym_db.RegisterMessage(ProtoLocation)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
